@@ -8,7 +8,8 @@ test_that("make slides", {
   data(mc_sme_top_domains)
   data(mc_threat_communities)
 
-  tmpdir <- tempdir(check = TRUE)
+  tmpdir <- file.path(tempdir(), "collector")
+  dir.create(tmpdir, showWarnings = FALSE)
 
   ques <- tidyrisk_question_set(domains = mc_domains,
                                 calibration = calibration_questions,
@@ -20,5 +21,5 @@ test_that("make slides", {
   make_slides("Natalie Wade", ques, tmpdir)
   file_location <- file.path(tmpdir, "natalie_wade.html")
   expect_true(file.exists(file_location))
-  unlink(file_location)
+  unlink(tmpdir, recursive = TRUE)
 })
